Documentation
¶
Overview ¶
Package media provides utilities for working with audio and video files.
Index ¶
- func CheckFFmpeg() error
- func CheckFFprobe() error
- func GetAudioDuration(path string) (time.Duration, error)
- func GetAudioDurationMs(path string) (int, error)
- func GetDuration(path string) (time.Duration, error)
- func GetDurationMs(path string) (int, error)
- func GetVideoDuration(path string) (time.Duration, error)
- func GetVideoDurationMs(path string) (int, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CheckFFmpeg ¶
func CheckFFmpeg() error
CheckFFmpeg verifies that ffmpeg is installed and accessible.
func CheckFFprobe ¶
func CheckFFprobe() error
CheckFFprobe verifies that ffprobe is installed and accessible.
func GetAudioDuration ¶
GetAudioDuration returns the duration of an audio file using ffprobe. This consolidates the duplicate implementations that were in: - pkg/tts/audio.go - pkg/audio/player.go - pkg/video/image_video.go
func GetAudioDurationMs ¶
GetAudioDurationMs returns the audio duration in milliseconds.
func GetDuration ¶
GetDuration returns the duration of a media file (audio or video).
func GetDurationMs ¶
GetDurationMs returns the duration in milliseconds.
func GetVideoDuration ¶
GetVideoDuration returns the duration of a video file using ffprobe.
func GetVideoDurationMs ¶
GetVideoDurationMs returns the video duration in milliseconds.
Types ¶
This section is empty.