parser

package
v0.4.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 21, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Presentation

type Presentation struct {
	Frontmatter string
	Slides      []Slide
}

Presentation represents the parsed Marp presentation

func ParseMarpFile

func ParseMarpFile(content string) (*Presentation, error)

ParseMarpFile parses a Marp markdown file and extracts slides with voiceovers

type Slide

type Slide struct {
	Index              int
	Content            string
	Voiceover          string
	PauseDurations     []int // milliseconds
	TotalPauseDuration int
}

Slide represents a single slide with content and voiceover

Jump to